==> eiffelstudio-18.11.10.2592.tar: F_code/C4/ew174.c <==
/*
 * Code for class EW_ERROR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew174.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_ERROR}.make_with_reason */
void F226_2638 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("make_with_reason", 225, Current, 0, 1, 2704);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {EW_ERROR}.make */
void F226_2639 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg3);
	RTLR(3,arg4);
	RTLR(4,arg5);
	RTLIU(5);
	
	RTEAA("make", 225, Current, 0, 5, 2705);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_) = (EIF_INTEGER_32) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg3;
	RTHOOK(4);
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg4;
	RTHOOK(5);
	RTAR(Current, arg5);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg5;
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {EW_ERROR}.file_name */
EIF_REFERENCE F226_2641 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {EW_ERROR}.original_text */
EIF_REFERENCE F226_2643 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {EW_ERROR}.substituted_text */
EIF_REFERENCE F226_2644 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {EW_ERROR}.reason */
EIF_REFERENCE F226_2645 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {EW_ERROR}.display */
void F226_2646 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,loc1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTEAA("display", 225, Current, 2, 0, 2711);
	RTGC;
	RTHOOK(1);
	tr1 = F224_2630(Current);
	tr2 = RTMS_EX_H("\011",1,9);
	F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
	RTHOOK(2);
	tr1 = F224_2630(Current);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2389[Dtype(Current)-226])(Current);
	F7_206(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
	RTHOOK(3);
	tr1 = F224_2630(Current);
	tr2 = RTMS_EX_H(" error",6,1983792498);
	F7_206(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
	RTHOOK(4);
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current) != NULL)) {
		RTHOOK(5);
		tr1 = F224_2630(Current);
		tr2 = RTMS_EX_H(" in file ",9,1126896160);
		F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(6);
		tr1 = F224_2630(Current);
		tr2 = *(EIF_REFERENCE *)(Current);
		F7_205(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(7);
		tr1 = F224_2630(Current);
		tr2 = RTMS_EX_H(" at line ",9,1997649184);
		F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(8);
		tr1 = F224_2630(Current);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_);
		tr2 = c_outi(ti4_1);
		F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
	}
	RTHOOK(9);
	F7_208(RTCV(F224_2630(Current)));
	RTHOOK(10);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(11);
		tr1 = F224_2630(Current);
		tr2 = RTMS_EX_H("\011Original text:    ",19,851182112);
		F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(12);
		tr1 = F224_2630(Current);
		F7_205(RTCW(tr1), loc1, (EIF_BOOLEAN) 0);
		RTHOOK(13);
		F7_208(RTCV(F224_2630(Current)));
	}
	RTHOOK(14);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		RTHOOK(15);
		tr1 = F224_2630(Current);
		tr2 = RTMS_EX_H("\011Substituted text: ",19,889581344);
		F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(16);
		tr1 = F224_2630(Current);
		F7_205(RTCW(tr1), loc2, (EIF_BOOLEAN) 0);
		RTHOOK(17);
		F7_208(RTCV(F224_2630(Current)));
	}
	RTHOOK(18);
	tr1 = F224_2630(Current);
	tr2 = RTMS_EX_H("\011Reason: ",9,1906271264);
	F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
	RTHOOK(19);
	F226_2647(Current);
	RTHOOK(20);
	F7_208(RTCV(F224_2630(Current)));
	RTHOOK(21);
	RTLE;
	RTEE;
}

/* {EW_ERROR}.display_reason */
void F226_2647 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_32 loc2 = (EIF_CHARACTER_32) 0;
	struct eif_ex_22 sloc3;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) sloc3.data;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_CHARACTER_8 tc1;
	RTLD;
	
	memset (&sloc3.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc3.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc3.overhead, eif_new_type(35, 0x00).id);
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,loc3);
	RTLR(4,tr3);
	RTLIU(5);
	
	RTEAA("display_reason", 225, Current, 3, 0, 2712);
	RTGC;
	RTHOOK(1);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1) + O4302[Dtype(tr1)-879]);
		if ((EIF_BOOLEAN) (loc1 > ti4_1)) break;
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		loc2 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4149[Dtype(tr1)-880])(RTCW(tr1), loc1);
		RTHOOK(4);
		tr1 = F224_2630(Current);
		tb1 = (loc2 <= 0xFF);
		if (tb1) {
			RTHOOK(5);
			tr2 = RTLNS(eif_new_type(884, 0x00).id, 884, _OBJSIZ_1_1_0_3_0_0_0_0_);
			tc1 = (EIF_CHARACTER_8) loc2;
			F883_5765(RTCW(tr2), tc1, ((EIF_INTEGER_32) 1L));
		} else {
			RTHOOK(6);
			tr3 = RTLNS(eif_new_type(881, 0x00).id, 881, _OBJSIZ_1_1_0_3_0_0_0_0_);
			F880_5601(RTCW(tr3), loc2, ((EIF_INTEGER_32) 1L));
			tr3 = F36_513(RTCW(loc3), tr3);
			tr2 = tr3;
		}
		F7_206(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(7);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\012';
		if ((EIF_BOOLEAN)(loc2 == tw1)) {
			RTHOOK(8);
			tr1 = F224_2630(Current);
			tr2 = RTMS_EX_H("\011",1,9);
			F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		}
		RTHOOK(9);
		loc1++;
	}
	RTHOOK(10);
	RTLE;
	RTEE;
}

void EIF_Minit174 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/ew174.c <==
/*
 * Code for class EW_ERROR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew174.h"
#include "eif_out.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_ERROR}.make_with_reason */
void F226_2640 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("make_with_reason", 225, Current, 0, 1, 2706);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {EW_ERROR}.make */
void F226_2641 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg3);
	RTLR(3,arg4);
	RTLR(4,arg5);
	RTLIU(5);
	
	RTEAA("make", 225, Current, 0, 5, 2707);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_) = (EIF_INTEGER_32) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg3;
	RTHOOK(4);
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg4;
	RTHOOK(5);
	RTAR(Current, arg5);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg5;
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {EW_ERROR}.display */
void F226_2648 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,loc1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTEAA("display", 225, Current, 2, 0, 2713);
	RTGC;
	RTHOOK(1);
	tr1 = F224_2632(Current);
	tr2 = RTMS_EX_H("\011",1,9);
	F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
	RTHOOK(2);
	tr1 = F224_2632(Current);
	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2391[Dtype(Current)-226])(Current);
	F7_206(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
	RTHOOK(3);
	tr1 = F224_2632(Current);
	tr2 = RTMS_EX_H(" error",6,1983792498);
	F7_206(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
	RTHOOK(4);
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current) != NULL)) {
		RTHOOK(5);
		tr1 = F224_2632(Current);
		tr2 = RTMS_EX_H(" in file ",9,1126896160);
		F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(6);
		tr1 = F224_2632(Current);
		F7_205(RTCW(tr1), *(EIF_REFERENCE *)(Current), (EIF_BOOLEAN) 0);
		RTHOOK(7);
		tr1 = F224_2632(Current);
		tr2 = RTMS_EX_H(" at line ",9,1997649184);
		F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(8);
		tr1 = F224_2632(Current);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_4_0_0_0_);
		tr2 = c_outi(ti4_1);
		F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
	}
	RTHOOK(9);
	F7_208(RTCV(F224_2632(Current)));
	RTHOOK(10);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(11);
		tr1 = F224_2632(Current);
		tr2 = RTMS_EX_H("\011Original text:    ",19,851182112);
		F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(12);
		tr1 = F224_2632(Current);
		F7_205(RTCW(tr1), loc1, (EIF_BOOLEAN) 0);
		RTHOOK(13);
		F7_208(RTCV(F224_2632(Current)));
	}
	RTHOOK(14);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		RTHOOK(15);
		tr1 = F224_2632(Current);
		tr2 = RTMS_EX_H("\011Substituted text: ",19,889581344);
		F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(16);
		tr1 = F224_2632(Current);
		F7_205(RTCW(tr1), loc2, (EIF_BOOLEAN) 0);
		RTHOOK(17);
		F7_208(RTCV(F224_2632(Current)));
	}
	RTHOOK(18);
	tr1 = F224_2632(Current);
	tr2 = RTMS_EX_H("\011Reason: ",9,1906271264);
	F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
	RTHOOK(19);
	F226_2649(Current);
	RTHOOK(20);
	F7_208(RTCV(F224_2632(Current)));
	RTHOOK(21);
	RTLE;
	RTEE;
}

/* {EW_ERROR}.display_reason */
void F226_2649 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_32 loc2 = (EIF_CHARACTER_32) 0;
	struct eif_ex_22 sloc3;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) sloc3.data;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_CHARACTER_8 tc1;
	RTLD;
	
	memset (&sloc3.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc3.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc3.overhead, eif_new_type(35, 0x00).id);
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,loc3);
	RTLR(4,tr3);
	RTLIU(5);
	
	RTEAA("display_reason", 225, Current, 3, 0, 2714);
	RTGC;
	RTHOOK(1);
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	for (;;) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1) + O4323[Dtype(tr1)-879]);
		if ((EIF_BOOLEAN) (loc1 > ti4_1)) break;
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		loc2 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4170[Dtype(RTCW(tr1))-880])(tr1, loc1);
		RTHOOK(4);
		tr1 = F224_2632(Current);
		tb1 = (loc2 <= 0xFF);
		if (tb1) {
			RTHOOK(5);
			tr2 = RTLNS(eif_new_type(884, 0x00).id, 884, _OBJSIZ_1_1_0_3_0_0_0_0_);
			tc1 = (EIF_CHARACTER_8) loc2;
			F883_5786(RTCW(tr2), tc1, ((EIF_INTEGER_32) 1L));
		} else {
			RTHOOK(6);
			tr3 = RTLNS(eif_new_type(881, 0x00).id, 881, _OBJSIZ_1_1_0_3_0_0_0_0_);
			F880_5622(RTCW(tr3), loc2, ((EIF_INTEGER_32) 1L));
			tr3 = F36_513(RTCW(loc3), tr3);
			tr2 = tr3;
		}
		F7_206(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		RTHOOK(7);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\012';
		if ((EIF_BOOLEAN)(loc2 == tw1)) {
			RTHOOK(8);
			tr1 = F224_2632(Current);
			tr2 = RTMS_EX_H("\011",1,9);
			F7_204(RTCW(tr1), tr2, (EIF_BOOLEAN) 0);
		}
		RTHOOK(9);
		loc1++;
	}
	RTHOOK(10);
	RTLE;
	RTEE;
}

void EIF_Minit174 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
